@@ -25,6 +25,7 @@ class JobServer ():
   configfile="/etc/mprov/jobserver.yaml"
   ip_address = ""
   myaddress = ""
+  loadmon=True
   plugin_dir = os.path.dirname(os.path.realpath(__file__)) + '/plugins/'
   jobmodules = []
   running_threads = {}
@@ -120,6 +121,10 @@ class JobServer ():
     for config_entry in self.config_data['global'].keys():
       try:
         getattr(self, config_entry)
+        if config_entry == "mprovURL":
+          # add a trailing slash if one doesn't exist.
+          if self.config_data['global'][config_entry][-1] != "/":
+            self.config_data['global'][config_entry] += "/"
         setattr(self, config_entry, self.config_data['global'][config_entry])
       except:
         print("Error: " + config_entry + " is not a valid config entry in 'global'.", file=sys.stderr)
@@ -156,7 +161,7 @@ class JobServer ():
             # first check if the thread is done running.
             if mod in self.running_threads: 
               # check if this thread is still running
-              if not self.running_threads[mod].isAlive() :
+              if not self.running_threads[mod].is_alive() :
                 # print ("Thread " + mod + " ended.")
                 # if it's done running remove it.
                 self.running_threads[mod].handled = True
@@ -280,9 +285,9 @@ class JobServer ():
         'name': myHostname,
         'address': self.ip_address,
         'jobmodules': self.jobmodules,
-        'one_minute_load': os.getloadavg()[0]
+        'one_minute_load': os.getloadavg()[2]
     }
-    if data['one_minute_load'] >= multiprocessing.cpu_count():
+    if data['one_minute_load'] >= multiprocessing.cpu_count() and self.config_data['loadmon']:
       print("Not Registering, high load.")
       return
     # print(self.config_data)
