@@ -6,7 +6,9 @@ from socket import AF_INET, AF_INET6
 
 jenv = Environment(
     loader=PackageLoader("mprov_jobserver"),
-    autoescape=select_autoescape()
+    autoescape=select_autoescape(),
+    trim_blocks=True,
+    lstrip_blocks=True,
 )
 
 class DnsmasqDNSConfig(JobServerPlugin):
@@ -46,7 +48,8 @@ class DnsmasqDNSConfig(JobServerPlugin):
                                     'ipaddress': address['addr'],
                                     'ipv6ll': '',
                                     'hostname': self.hostname,
-                                    'domain': network['domain'] + f"# {iface}"
+                                    'domain': network['domain'] + f"# {iface}",
+                                    'hostaliases': ""
                                 })
             # # grab and add the LL ipv6 ip addresses.
             # if AF_INET6 in netifaces.ifaddresses(iface):
@@ -70,6 +73,7 @@ class DnsmasqDNSConfig(JobServerPlugin):
         # get the network informatioin
         response = self.js.session.get( self.js.mprovURL + 'networks/?managedns=True')
         data = {
+            'hostname': self.hostname,
             'networks': response.json(),
             'enableDNS': True,
         }
@@ -83,15 +87,15 @@ class DnsmasqDNSConfig(JobServerPlugin):
             
         
             # grab the system network interfaces that are on this network.
+            response = None
+            data_hosts = { 'hosts': [] }
             print(self.js.mprovURL + 'networkinterfaces/?network=' + network['slug'])
             response = self.js.session.get( self.js.mprovURL + 'networkinterfaces/?network=' + network['slug'])
-            if not self.checkHTTPStatus(response.status_code):
-                print(f"Error: Issue with network {network['slug']}")
-                continue
-            data_hosts = {
-                'enableDNS': True,
-                'hosts': response.json(),
-            }
+            if self.checkHTTPStatus(response.status_code):
+                data_hosts = {
+                    'enableDNS': True,
+                    'hosts': response.json(),
+                }
             # add ourself if we are listening on this net
             data_hosts['hosts'].extend(self._addSelfToNet(network))
 
@@ -107,8 +111,9 @@ class DnsmasqDNSConfig(JobServerPlugin):
                             'ipaddress': bmc['ipaddress'],
                             'ipv6ll': "", 
                             'mac': bmc['mac'],
-                            'hostname': bmc['system']['hostname'] + '-bmc',
-                            'domain': network['domain']
+                            'hostname': bmc['system']['hostname'],
+                            'domain': network['domain'],
+                            'hostaliases': ""
                         }
                         data_hosts['hosts'].append(tmpHost)
                 except:
@@ -116,6 +121,7 @@ class DnsmasqDNSConfig(JobServerPlugin):
             # merge in the switches
             response = self.js.session.get( self.js.mprovURL + 'switches/?network=' + network['slug'])
             data_hosts['hosts'] = data_hosts['hosts'] + (response.json())
+            
             # print(data_hosts)
             for idx, host in enumerate(data_hosts['hosts']):
                 if 'mgmt_mac' in host:
