@@ -9,6 +9,7 @@ import json
 class UpdateRepo(JobServerPlugin):
   repo = None
   repoDir = ""
+  jobid = None
   def load_config(self):
     # Do a GET to see if our ostype exists, if it does, patch it, if it doesn't, post it.
     # if 'repo-server' not in self.js.jobmodules:
@@ -44,10 +45,12 @@ class UpdateRepo(JobServerPlugin):
     os.chdir(f"{self.repoDir}/")
     baseURL = repoDetails['repo_package_url']
     print("Grabbing repository mirror: " + baseURL)
-    if os.system(f"wget --mirror -nH --cut-dirs={pathDepth} -np -P {self.repo['id']}/ {baseURL}" ):
+    #if os.system(f"wget --mirror -nH --cut-dirs={pathDepth} -np -P {self.repo['id']}/ {baseURL}" ):
+    if os.system(f"dnf reposync --repofrompath {self.repo['id']},\"{self.repo['repo_package_url']}\" --repo {self.repo['id']} --destdir=./ --download-metadata"):
       print("Error: unable to get repo: " + baseURL)
-      self.js.update_job_status(self.jobModule, 3, jobquery='jobserver=' + str(self.js.id) + '&status=2')
+      self.js.update_job_status(self.jobModule, 3, jobid=self.jobid, jobquery='jobserver=' + str(self.js.id) + '&status=2')
       return
+    
     # update the 'jobservers' field to be us, so that the 
     data = {
       'id': self.repo['id'],
@@ -58,5 +61,5 @@ class UpdateRepo(JobServerPlugin):
     }
     print(json.dumps(data))
     response = self.js.session.patch(self.js.mprovURL + 'repos/' + str(data['id']) + '/', data=json.dumps(data))
-    self.js.update_job_status(self.jobModule, 4, jobquery='jobserver=' + str(self.js.id) + '&status=2')
+    self.js.update_job_status(self.jobModule, 4, jobid=self.jobid, jobquery='jobserver=' + str(self.js.id) + '&status=2')
     return 
\ No newline at end of file
